package com.ruoyi.zongzhi.service;

import java.util.List;
import com.ruoyi.zongzhi.domain.TcQlzxxdsj;

/**
 * 清郎专项行动数据统计Service接口
 * 
 * @author ruoyi
 * @date 2023-08-28
 */
public interface ITcQlzxxdsjService 
{
    /**
     * 查询清郎专项行动数据统计
     * 
     * @param id 清郎专项行动数据统计主键
     * @return 清郎专项行动数据统计
     */
    public TcQlzxxdsj selectTcQlzxxdsjById(Long id);

    /**
     * 查询清郎专项行动数据统计列表
     * 
     * @param tcQlzxxdsj 清郎专项行动数据统计
     * @return 清郎专项行动数据统计集合
     */
    public List<TcQlzxxdsj> selectTcQlzxxdsjList(TcQlzxxdsj tcQlzxxdsj);

    /**
     * 新增清郎专项行动数据统计
     * 
     * @param tcQlzxxdsj 清郎专项行动数据统计
     * @return 结果
     */
    public int insertTcQlzxxdsj(TcQlzxxdsj tcQlzxxdsj);

    /**
     * 修改清郎专项行动数据统计
     * 
     * @param tcQlzxxdsj 清郎专项行动数据统计
     * @return 结果
     */
    public int updateTcQlzxxdsj(TcQlzxxdsj tcQlzxxdsj);

    /**
     * 批量删除清郎专项行动数据统计
     * 
     * @param ids 需要删除的清郎专项行动数据统计主键集合
     * @return 结果
     */
    public int deleteTcQlzxxdsjByIds(Long[] ids);

    /**
     * 删除清郎专项行动数据统计信息
     * 
     * @param id 清郎专项行动数据统计主键
     * @return 结果
     */
    public int deleteTcQlzxxdsjById(Long id);
}
