package com.ruoyi.zongzhi.controller;

import java.util.List;
import io.swagger.annotations.Api;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.zongzhi.domain.TcQlzxxdsj;
import com.ruoyi.zongzhi.service.ITcQlzxxdsjService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 清郎专项行动数据统计Controller
 * 
 * @author ruoyi
 * @date 2023-08-28
 */
@RestController
@RequestMapping("/zongzhi/qlzxxdsj")
@Api(tags = " 清郎专项行动数据统计")
public class TcQlzxxdsjController extends BaseController
{
    @Autowired
    private ITcQlzxxdsjService tcQlzxxdsjService;

    /**
     * 查询清郎专项行动数据统计列表
     */
    @GetMapping("/list")
    public TableDataInfo list(TcQlzxxdsj tcQlzxxdsj)
    {
        startPage();
        List<TcQlzxxdsj> list = tcQlzxxdsjService.selectTcQlzxxdsjList(tcQlzxxdsj);
        return getDataTable(list);
    }

    /**
     * 导出清郎专项行动数据统计列表
     */
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcQlzxxdsj tcQlzxxdsj)
    {
        List<TcQlzxxdsj> list = tcQlzxxdsjService.selectTcQlzxxdsjList(tcQlzxxdsj);
        ExcelUtil<TcQlzxxdsj> util = new ExcelUtil<TcQlzxxdsj>(TcQlzxxdsj.class);
        util.exportExcel(response, list, "清郎专项行动数据统计数据");
    }

    /**
     * 获取清郎专项行动数据统计详细信息
     */

    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcQlzxxdsjService.selectTcQlzxxdsjById(id));
    }

    /**
     * 新增清郎专项行动数据统计
     */

    @PostMapping
    public AjaxResult add(@RequestBody TcQlzxxdsj tcQlzxxdsj)
    {
        tcQlzxxdsj.setIsStatus(true);
        return toAjax(tcQlzxxdsjService.insertTcQlzxxdsj(tcQlzxxdsj));
    }

    /**
     * 修改清郎专项行动数据统计
     */

    @PutMapping
    public AjaxResult edit(@RequestBody TcQlzxxdsj tcQlzxxdsj)
    {
        return toAjax(tcQlzxxdsjService.updateTcQlzxxdsj(tcQlzxxdsj));
    }

    /**
     * 删除清郎专项行动数据统计
     */

	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcQlzxxdsjService.deleteTcQlzxxdsjByIds(ids));
    }
}
